==> huaweicloudsdkidentitycenter-3.1.127-py2.py3-none-any.whl: huaweicloudsdkidentitycenter/v1/model/list_managed_roles_in_permission_set_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListManagedRolesInPermissionSetResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'attached_managed_roles': 'list[ResourceAttachedManagedPolicyDto]',
        'page_info': 'PageInfoDto'
    }

    attribute_map = {
        'attached_managed_roles': 'attached_managed_roles',
        'page_info': 'page_info'
    }

    def __init__(self, attached_managed_roles=None, page_info=None):
        """ListManagedRolesInPermissionSetResponse

        The model defined in huaweicloud sdk

        :param attached_managed_roles: IAM系统策略列表
        :type attached_managed_roles: list[:class:`huaweicloudsdkidentitycenter.v1.ResourceAttachedManagedPolicyDto`]
        :param page_info: 
        :type page_info: :class:`huaweicloudsdkidentitycenter.v1.PageInfoDto`
        """
        
        super(ListManagedRolesInPermissionSetResponse, self).__init__()

        self._attached_managed_roles = None
        self._page_info = None
        self.discriminator = None

        if attached_managed_roles is not None:
            self.attached_managed_roles = attached_managed_roles
        if page_info is not None:
            self.page_info = page_info

    @property
    def attached_managed_roles(self):
        """Gets the attached_managed_roles of this ListManagedRolesInPermissionSetResponse.

        IAM系统策略列表

        :return: The attached_managed_roles of this ListManagedRolesInPermissionSetResponse.
        :rtype: list[:class:`huaweicloudsdkidentitycenter.v1.ResourceAttachedManagedPolicyDto`]
        """
        return self._attached_managed_roles

    @attached_managed_roles.setter
    def attached_managed_roles(self, attached_managed_roles):
        """Sets the attached_managed_roles of this ListManagedRolesInPermissionSetResponse.

        IAM系统策略列表

        :param attached_managed_roles: The attached_managed_roles of this ListManagedRolesInPermissionSetResponse.
        :type attached_managed_roles: list[:class:`huaweicloudsdkidentitycenter.v1.ResourceAttachedManagedPolicyDto`]
        """
        self._attached_managed_roles = attached_managed_roles

    @property
    def page_info(self):
        """Gets the page_info of this ListManagedRolesInPermissionSetResponse.

        :return: The page_info of this ListManagedRolesInPermissionSetResponse.
        :rtype: :class:`huaweicloudsdkidentitycenter.v1.PageInfoDto`
        """
        return self._page_info

    @page_info.setter
    def page_info(self, page_info):
        """Sets the page_info of this ListManagedRolesInPermissionSetResponse.

        :param page_info: The page_info of this ListManagedRolesInPermissionSetResponse.
        :type page_info: :class:`huaweicloudsdkidentitycenter.v1.PageInfoDto`
        """
        self._page_info = page_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListManagedRolesInPermissionSetResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkidentitycenter-3.1.145-py2.py3-none-any.whl: huaweicloudsdkidentitycenter/v1/model/list_managed_roles_in_permission_set_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListManagedRolesInPermissionSetResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'attached_managed_roles': 'list[ResourceAttachedManagedPolicyDto]',
        'page_info': 'PageInfoDto'
    }

    attribute_map = {
        'attached_managed_roles': 'attached_managed_roles',
        'page_info': 'page_info'
    }

    def __init__(self, attached_managed_roles=None, page_info=None):
        r"""ListManagedRolesInPermissionSetResponse

        The model defined in huaweicloud sdk

        :param attached_managed_roles: IAM系统策略列表
        :type attached_managed_roles: list[:class:`huaweicloudsdkidentitycenter.v1.ResourceAttachedManagedPolicyDto`]
        :param page_info: 
        :type page_info: :class:`huaweicloudsdkidentitycenter.v1.PageInfoDto`
        """
        
        super(ListManagedRolesInPermissionSetResponse, self).__init__()

        self._attached_managed_roles = None
        self._page_info = None
        self.discriminator = None

        if attached_managed_roles is not None:
            self.attached_managed_roles = attached_managed_roles
        if page_info is not None:
            self.page_info = page_info

    @property
    def attached_managed_roles(self):
        r"""Gets the attached_managed_roles of this ListManagedRolesInPermissionSetResponse.

        IAM系统策略列表

        :return: The attached_managed_roles of this ListManagedRolesInPermissionSetResponse.
        :rtype: list[:class:`huaweicloudsdkidentitycenter.v1.ResourceAttachedManagedPolicyDto`]
        """
        return self._attached_managed_roles

    @attached_managed_roles.setter
    def attached_managed_roles(self, attached_managed_roles):
        r"""Sets the attached_managed_roles of this ListManagedRolesInPermissionSetResponse.

        IAM系统策略列表

        :param attached_managed_roles: The attached_managed_roles of this ListManagedRolesInPermissionSetResponse.
        :type attached_managed_roles: list[:class:`huaweicloudsdkidentitycenter.v1.ResourceAttachedManagedPolicyDto`]
        """
        self._attached_managed_roles = attached_managed_roles

    @property
    def page_info(self):
        r"""Gets the page_info of this ListManagedRolesInPermissionSetResponse.

        :return: The page_info of this ListManagedRolesInPermissionSetResponse.
        :rtype: :class:`huaweicloudsdkidentitycenter.v1.PageInfoDto`
        """
        return self._page_info

    @page_info.setter
    def page_info(self, page_info):
        r"""Sets the page_info of this ListManagedRolesInPermissionSetResponse.

        :param page_info: The page_info of this ListManagedRolesInPermissionSetResponse.
        :type page_info: :class:`huaweicloudsdkidentitycenter.v1.PageInfoDto`
        """
        self._page_info = page_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListManagedRolesInPermissionSetResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
